@@ -12,7 +12,6 @@
 
 from neutron_lib.api import converters
 from neutron_lib.api.definitions import constants as api_const
-from neutron_lib import constants
 from neutron_lib.db import constants as db_const
 
 # The alias of the extension.
@@ -62,15 +61,15 @@ RESOURCE_ATTRIBUTE_MAP = {
         'firewall_policy_id': {'allow_post': False, 'allow_put': False,
                                'validate': {'type:uuid_or_none': None},
                                'is_visible': True},
-        'public': {'allow_post': True, 'allow_put': True,
+        'shared': {'allow_post': True, 'allow_put': True,
                    'default': False, 'is_visible': True,
                    'convert_to': converters.convert_to_boolean,
                    'required_by_policy': True, 'enforce_policy': True},
-        'protocol': {'allow_post': True, 'allow_put': True,
-                     'is_visible': True, 'default': None,
-                     'convert_to': converters.convert_to_protocol,
-                     'validate': {'type:values':
-                                  constants.IPTABLES_PROTOCOL_MAP}},
+        'protocol': {
+            'allow_post': True, 'allow_put': True,
+            'is_visible': True, 'default': None,
+            'convert_to': converters.convert_to_protocol,
+            'validate': {'type:values': api_const.FW_PROTOCOL_VALUES}},
         'ip_version': {'allow_post': True, 'allow_put': True,
                        'default': 4, 'convert_to': converters.convert_to_int,
                        'validate': {'type:values': [4, 6]},
@@ -116,7 +115,7 @@ RESOURCE_ATTRIBUTE_MAP = {
                            'convert_to': converters.convert_to_boolean},
         'status': {'allow_post': False, 'allow_put': False,
                    'is_visible': True},
-        'public': {'allow_post': True, 'allow_put': True, 'default': False,
+        'shared': {'allow_post': True, 'allow_put': True, 'default': False,
                    'convert_to': converters.convert_to_boolean,
                    'is_visible': True, 'required_by_policy': True,
                    'enforce_policy': True},
@@ -157,7 +156,7 @@ RESOURCE_ATTRIBUTE_MAP = {
                         'validate': {'type:string':
                                      db_const.DESCRIPTION_FIELD_SIZE},
                         'is_visible': True, 'default': ''},
-        'public': {'allow_post': True, 'allow_put': True, 'default': False,
+        'shared': {'allow_post': True, 'allow_put': True, 'default': False,
                    'convert_to': converters.convert_to_boolean,
                    'is_visible': True, 'required_by_policy': True,
                    'enforce_policy': True},
@@ -182,6 +181,10 @@ ACTION_MAP = {
     'firewall_policy': {'insert_rule': 'PUT', 'remove_rule': 'PUT'},
 }
 
+# The action status.
+ACTION_STATUS = {
+}
+
 # The list of required extensions.
 REQUIRED_EXTENSIONS = [
 ]
